@@ -40,7 +40,7 @@ from .strategy_utils import (
 )
 from .strategy_utils.gmm import class_probs, gmm_evaluate, gmm_fit_, compute_density_
 from ..utils.general import json_dump, json_load
-from ..utils.get_embeddings import get_embeddings, get_grad_embeddings
+from ..utils.get_embeddings import get_embeddings
 from ..utils.transformers_dataset import TransformersDataset
 from ..model_wrappers.transformers import WrapperCls, WrapperNer, WrapperAts, WrapperNmt
 
@@ -952,148 +952,6 @@ def calculate_ddu_scores(
     )
 
 
-def calculate_badge_scores(
-    model_wrapper,
-    data_test,
-    logits,
-    use_activation: bool = False,
-    use_spectralnorm: bool = False,
-    data_is_tokenized=False,
-    data_config=None,
-    batch_size=100,
-    to_numpy=True,
-):
-    data_config = data_config if data_config is not None else model_wrapper.data_config
-    kwargs = dict(
-        # General
-        model=model_wrapper.model,
-        prepare_model=True,
-        batch_size=batch_size,
-        to_numpy=False,
-        data_is_tokenized=data_is_tokenized,
-        tokenizer=model_wrapper.tokenizer,
-        task=model_wrapper.task,
-        text_name=data_config["text_name"],
-        label_name=data_config["label_name"],
-    )
-    """Return the loss gradient with respect to the penultimate layer for BADGE"""
-    pooled_output = get_grad_embeddings(dataloader_or_data=data_test, **kwargs).to(
-        model_wrapper.model.device
-    )
-    batch_size, num_classes = logits.shape
-    probs = nn.functional.softmax(
-        torch.Tensor(logits).to(model_wrapper.model.device), dim=-1
-    )
-    preds = probs.argmax(dim=1)
-    preds_oh = nn.functional.one_hot(preds, num_classes=num_classes)
-    preds_oh = preds_oh.type(torch.cuda.FloatTensor)
-    scales = probs - preds_oh
-    grads_3d = torch.einsum("bi,bj->bij", scales, pooled_output)
-    grads = grads_3d.view(batch_size, -1)
-    return grads
-
-
-# Contrastive Active Learning (CAL) https://aclanthology.org/2021.emnlp-main.51.pdf
-def calculate_cal_scores(
-    model_wrapper,
-    data_train,
-    data_test,
-    probas,
-    train_probas,
-    use_activation: bool = False,
-    use_spectralnorm: bool = False,
-    data_is_tokenized=False,
-    data_config=None,
-    batch_size=100,
-    to_numpy=True,
-    num_nei=10,
-    operator="mean",
-):
-    data_config = data_config if data_config is not None else model_wrapper.data_config
-    kwargs = dict(
-        # General
-        model=model_wrapper.model,
-        prepare_model=True,
-        batch_size=batch_size,
-        to_numpy=False,
-        # DDU
-        use_activation=use_activation,
-        use_spectralnorm=use_spectralnorm,
-        # Tokenization
-        data_is_tokenized=data_is_tokenized,
-        tokenizer=model_wrapper.tokenizer,
-        task=model_wrapper.task,
-        text_name=data_config["text_name"],
-        label_name=data_config["label_name"],
-    )
-
-    train_embeddings = (
-        get_embeddings(dataloader_or_data=data_train, **kwargs).detach().cpu()
-    )
-    test_embeddings = (
-        get_embeddings(dataloader_or_data=data_test, **kwargs).detach().cpu()
-    )
-
-    if not isinstance(data_train, TransformersDataset):
-        data_train = TransformersDataset(data_train)
-    train_labels = _get_labels(data_train, data_config)
-
-    distances = None
-    num_adv = None
-
-    neigh = KNeighborsClassifier(n_neighbors=num_nei)
-    neigh.fit(X=train_embeddings, y=np.array(train_labels))
-
-    criterion = torch.nn.KLDivLoss(reduction="none")
-
-    kl_scores = []
-    num_adv = 0
-    distances = []
-    pairs = []
-    for unlab_i, candidate in enumerate(
-        tqdm(
-            zip(test_embeddings, probas),
-            desc="Finding neighbours for every unlabeled data point",
-        )
-    ):
-        # find indices of closesest "neighbours" in train set
-        unlab_representation, unlab_logit = candidate
-        distances_, neighbours = neigh.kneighbors(
-            X=[candidate[0].numpy()], return_distance=True
-        )
-        distances.append(distances_[0])
-
-        # remove outliers?
-        # cur_mean_dist = np.max(distances_[0])
-
-        labeled_neighbours_labels = train_labels[neighbours[0]]
-        preds_neigh = [np.argmax(train_probas[n], axis=1) for n in neighbours]
-        neigh_prob = torch.nn.functional.softmax(
-            torch.Tensor(train_probas[neighbours]).to("cpu"), dim=-1
-        )
-        pred_candidate = [np.argmax(candidate[1])]
-
-        uda_softmax_temp = 1
-        candidate_log_prob = torch.nn.functional.log_softmax(
-            torch.Tensor(candidate[1] / uda_softmax_temp).to("cpu"), dim=-1
-        )
-        kl = np.array(
-            [
-                torch.sum(criterion(candidate_log_prob, n), dim=-1).numpy()
-                for n in neigh_prob
-            ]
-        )
-
-        if operator == "mean":
-            kl_scores.append(kl.mean())
-        elif operator == "max":
-            kl_scores.append(kl.max())
-        elif operator == "median":
-            kl_scores.append(np.median(kl))
-
-    return np.array(kl_scores)
-
-
 def _get_labels(data, data_config):
     if isinstance(data, DataLoader):
         data = data.dataset
